==> haskell-fast-logger-2.4.3-1-armv7h.pkg.tar.xz: usr/share/haskell/haskell-fast-logger/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: fast-logger
version: 2.4.3
id: fast-logger-2.4.3-07980efcfdf2821a6e4b588f1620bda1
key: fastl_7BE9K8lRSSNFghT3GZfXYp
license: BSD3
maintainer: Kazu Yamamoto <kazu@iij.ad.jp>
synopsis: A fast logging system
description:
    A fast logging system
category: System
author: Kazu Yamamoto <kazu@iij.ad.jp>
exposed: True
exposed-modules:
    System.Log.FastLogger System.Log.FastLogger.File
hidden-modules: System.Log.FastLogger.IO
                System.Log.FastLogger.FileIO System.Log.FastLogger.IORef
                System.Log.FastLogger.LogStr System.Log.FastLogger.Logger
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/fast-logger-2.4.3
library-dirs: /usr/lib/ghc-7.10.3/site-local/fast-logger-2.4.3
data-dir: /usr/share/arm-linux-ghc-7.10.3/fast-logger-2.4.3
hs-libraries: HSfast-logger-2.4.3-7BE9K8lRSSNFghT3GZfXYp
depends:
    array-0.5.1.0-a4b4f31b03b7779670557ea46745a386
    auto-update-0.1.3-4edf36ce78b71bfaad1ce3737442c65f
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
    directory-1.2.2.0-17b2023f9d7e8036d19e6b52b4f75c98
    filepath-1.4.0.0-73e0bec80594160bf6dd6cb25217c6bf
    text-1.2.2.1-18afbfeccf88d72c4b6e468c86d2b77d
haddock-interfaces: /usr/share/doc/haskell-fast-logger/html/fast-logger.haddock
haddock-html: /usr/share/doc/haskell-fast-logger/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"

==> haskell-fast-logger-2.4.6-2-armv7h.pkg.tar.xz: usr/share/haskell/haskell-fast-logger/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: fast-logger
version: 2.4.6
id: fast-logger-2.4.6-432abdc0f5b043114ea69b7c4625cae5
key: fastl_19wy1EF1tO5D8dxvuyIOiR
license: BSD3
maintainer: Kazu Yamamoto <kazu@iij.ad.jp>
synopsis: A fast logging system
description:
    A fast logging system
category: System
author: Kazu Yamamoto <kazu@iij.ad.jp>
exposed: True
exposed-modules:
    System.Log.FastLogger System.Log.FastLogger.File
    System.Log.FastLogger.Date
hidden-modules: System.Log.FastLogger.IO
                System.Log.FastLogger.FileIO System.Log.FastLogger.IORef
                System.Log.FastLogger.LogStr System.Log.FastLogger.Logger
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/fast-logger-2.4.6
library-dirs: /usr/lib/ghc-7.10.3/site-local/fast-logger-2.4.6
data-dir: /usr/share/arm-linux-ghc-7.10.3/fast-logger-2.4.6
hs-libraries: HSfast-logger-2.4.6-19wy1EF1tO5D8dxvuyIOiR
depends:
    array-0.5.1.0-a4b4f31b03b7779670557ea46745a386
    auto-update-0.1.4-5802161b0d99b2a30d57c95848e07a31
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
    directory-1.2.2.0-17b2023f9d7e8036d19e6b52b4f75c98
    easy-file-0.2.1-9b22ae8f4cbee2da82c99a0d82e5050c
    filepath-1.4.0.0-73e0bec80594160bf6dd6cb25217c6bf
    text-1.2.2.1-18afbfeccf88d72c4b6e468c86d2b77d
    unix-2.7.1.0-a583968f8d5891c6bf334fddb26b19a6
    unix-time-0.3.6-139be0d28d6f361941053e7ff9473819
haddock-interfaces: /usr/share/doc/haskell-fast-logger/html/fast-logger.haddock
haddock-html: /usr/share/doc/haskell-fast-logger/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
